package com.yunzhi.shigongli.common;

import com.github.binarywang.wxpay.bean.order.WxPayMpOrderResult;
import com.github.binarywang.wxpay.bean.request.WxPayRefundRequest;
import com.github.binarywang.wxpay.bean.request.WxPayUnifiedOrderRequest;
import com.github.binarywang.wxpay.bean.result.WxPayRefundResult;
import com.github.binarywang.wxpay.constant.WxPayConstants;
import com.github.binarywang.wxpay.service.WxPayService;
import com.yunzhi.shigongli.config.WeixinConfig;
import com.yunzhi.shigongli.entity.TaOrder;
import com.yunzhi.shigongli.entity.TaOrderSub;
import com.yunzhi.shigongli.entity.TaPerson;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;

@Component
public class WxPayUtils {
    @Autowired
    WeixinConfig config;

    @Autowired
    WxUtils wxUtils;

    /**
     * 下单
     * @param person
     * @param taOrder
     * @return
     * @throws Exception
     */
    public WxPayMpOrderResult createOrder(TaPerson person, TaOrder taOrder) throws Exception {
        LocalDateTime now = LocalDateTime.now();
        WxPayService payService = wxUtils.getPayService();

        WxPayUnifiedOrderRequest orderRequest = new WxPayUnifiedOrderRequest();
        orderRequest.setBody(taOrder.getDescription());
        orderRequest.setOutTradeNo(taOrder.getOrderId());
        orderRequest.setTotalFee(taOrder.getCharges());
        orderRequest.setOpenid(person.getOpenid());
        orderRequest.setNotifyUrl(config.getPay().getNotifyUrl());
        orderRequest.setSpbillCreateIp("218.91.253.51");  // 随便写个 IP
        orderRequest.setTimeStart(DateUtils.toString(now, "yyyyMMddHHmmss"));
        // 默认支付 30 分钟有效期
        orderRequest.setTimeExpire(DateUtils.toString(now.plusMinutes(30), "yyyyMMddHHmmss"));

        WxPayMpOrderResult payResult = payService.createOrder(orderRequest);
        return payResult;
    }

    /**
     * 订单退款
     * @param taOrder
     * @param cashback
     * @return
     * @throws Exception
     */
    public WxPayRefundResult refund(TaOrder taOrder, Integer cashback) throws Exception {
        WxPayService payService = wxUtils.getPayService();
        WxPayRefundRequest refundRequest = new WxPayRefundRequest();
        refundRequest.setOutTradeNo(taOrder.getOrderId());
        refundRequest.setOutRefundNo("R"+taOrder.getOrderId());
        refundRequest.setTotalFee(taOrder.getCharges());
        refundRequest.setRefundFee(taOrder.getCharges() - cashback);
        refundRequest.setNotifyUrl(config.getPay().getRefundNotifyUrl());
        WxPayRefundResult result = payService.refund(refundRequest);

        if (!WxPayConstants.ResultCode.SUCCESS.equals(result.getResultCode())) {
            throw new Exception(result.getErrCodeDes());
        }

        return result;
    }

    /**
     * 订单项目退款
     * @param taOrder
     * @param taOrderSub
     * @return
     * @throws Exception
     */
    public WxPayRefundResult refund(TaOrder taOrder, TaOrderSub taOrderSub) throws Exception {
        WxPayService payService = wxUtils.getPayService();
        WxPayRefundRequest refundRequest = new WxPayRefundRequest();
        refundRequest.setOutTradeNo(taOrderSub.getOrderId());
        refundRequest.setOutRefundNo("R"+taOrderSub.getSubOrderId());
        refundRequest.setTotalFee(taOrder.getCharges());
        refundRequest.setRefundFee(taOrderSub.getCharges() - taOrderSub.getCashback());
        refundRequest.setNotifyUrl(config.getPay().getRefundNotifyUrl());
        WxPayRefundResult result = payService.refund(refundRequest);

        if (!WxPayConstants.ResultCode.SUCCESS.equals(result.getResultCode())) {
            throw new Exception(result.getErrCodeDes());
        }

        return result;
    }
}
