package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.vo.CommissionSettlementVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.shigongli.service.ITaHotelAccountService;
import com.yunzhi.shigongli.entity.TaHotelAccount;

/**
 * <p>
    * 民宿账户 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "民宿账户")
@RestController
@RequestMapping("/")
public class TaHotelAccountController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHotelAccountController.class);

    @Autowired
    public ITaHotelAccountService iTaHotelAccountService;

    /**
     * 佣金结算
     * @param commissionSettlementVO
     * @return
     * @throws Exception
     */
    @PutMapping("/admin/hotelAccount/commission/settlement")
    @ApiOperation(value="佣金结算", notes = "佣金结算", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean commissionSettlement(@ApiParam("结算佣金") @RequestBody CommissionSettlementVO commissionSettlementVO) throws Exception {
        String hotelId = commissionSettlementVO.getTargetId();
        if (StringUtils.isEmpty(hotelId)) {
            return ResponseBean.error("未找到结算民宿对象", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (null == commissionSettlementVO.getCharges() || commissionSettlementVO.getCharges() < 1) {
            return ResponseBean.error("请设置有效的结算金额", ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaHotelAccount taHotelAccount = iTaHotelAccountService.getByHotel(hotelId);
        if (null == taHotelAccount) {
            return ResponseBean.error("未找到有效的结算民宿对象", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (taHotelAccount.getBrokerageCharges() - taHotelAccount.getPaidCharges() < commissionSettlementVO.getCharges()) {
            return ResponseBean.error("佣金不足", ResponseBean.ERROR_MISSING_PARAMS);
        }

        boolean success = iTaHotelAccountService.commissionSettlement(taHotelAccount, commissionSettlementVO.getCharges());
        if (success) {
            return ResponseBean.success("success");
        } else {
            return ResponseBean.error("结算失败请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }


//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taHotelAccount",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taHotelAccountList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaHotelAccount> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaHotelAccount> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaHotelAccount> result = iTaHotelAccountService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }
//
//    /**
//     * 保存对象
//     * @param taHotelAccount 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taHotelAccount",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taHotelAccountAdd(@ApiParam("保存内容") @RequestBody TaHotelAccount taHotelAccount) throws Exception{
//
//        if (iTaHotelAccountService.save(taHotelAccount)){
//            return ResponseBean.success(taHotelAccount);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taHotelAccount/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taHotelAccountDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaHotelAccountService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taHotelAccount 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taHotelAccount/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taHotelAccountUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaHotelAccount taHotelAccount) throws Exception{
//
//        if (iTaHotelAccountService.updateById(taHotelAccount)){
//            return ResponseBean.success(iTaHotelAccountService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taHotelAccount/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taHotelAccountGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaHotelAccountService.getById(id));
//    }
}
