package com.yunzhi.shigongli.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaQrcodeService;
import cn.binarywang.wx.miniapp.bean.WxMaCodeLineColor;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.OSSUtils;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.common.WxUtils;
import com.yunzhi.shigongli.entity.TaMiniappQrcode;
import com.yunzhi.shigongli.mapper.TaMiniappQrcodeMapper;
import com.yunzhi.shigongli.service.ITaMiniappQrcodeService;
import com.yunzhi.shigongli.vo.QrCodeParamsVO;
import me.chanjar.weixin.common.error.WxErrorException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import sun.security.krb5.internal.PAData;

import java.io.File;
import java.io.FileNotFoundException;
import java.time.LocalDateTime;

/**
 * <p>
 * 访问人次 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaMiniappQrcodeImpl extends BaseServiceImpl<TaMiniappQrcodeMapper, TaMiniappQrcode> implements ITaMiniappQrcodeService {

    @Autowired
    WxUtils wxUtils;

    @Autowired
    OSSUtils ossUtils;

    @Autowired
    TaMiniappQrcodeMapper miniappQrcodeMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public String createQrCode(QrCodeParamsVO qrCodeParamsVO) throws Exception {
        if (null == qrCodeParamsVO || StringUtils.isEmpty(qrCodeParamsVO.getPage())) {
            throw new Exception("小程序码生成参数为空");
        }

        if (StringUtils.isEmpty(qrCodeParamsVO.getType())) {
            throw new Exception("小程序码页面参数非法");
        }

        // 页面地址, 不能以 / 开头
        String page = qrCodeParamsVO.getPage();
        if (page.startsWith("/")) {
            page = page.substring(1);
        }

        // 页面参数
        String secen = qrCodeParamsVO.getSceneQueryString();

        // 小程序ID
        String miniappId = wxUtils.getService().getWxMaConfig().getAppid();

        // 先去查询数据库中是否已经存在相同参数的小程序码
        LambdaQueryWrapper<TaMiniappQrcode> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaMiniappQrcode::getMiniappId, miniappId)
                .eq(TaMiniappQrcode::getPage, page)
                .eq(!StringUtils.isEmpty(secen), TaMiniappQrcode::getScene, secen)
                .orderByDesc(TaMiniappQrcode::getCreateDate)
                .last("limit 1");

        // 如果存在, 则直接返回
        TaMiniappQrcode origin = getOne(queryWrapper);
        if (null != origin) {
            return origin.getQrImage();
        }

        // 否则, 则新生成一个
        // 先入库
        TaMiniappQrcode taMiniappQrcode = new TaMiniappQrcode();
        taMiniappQrcode.setMiniappId(miniappId);
        taMiniappQrcode.setPage(page);
        taMiniappQrcode.setScene(secen);
        taMiniappQrcode.setCreateDate(LocalDateTime.now());
        save(taMiniappQrcode);

        // 使用SDK生成
        WxUtils.AQrCodeParam param = new WxUtils.AQrCodeParam();
        param.setPage(page);
        param.setScene(taMiniappQrcode.getQrId().toString()); // 使用 qrId 作为 scene
        param.setWidth(860);
        param.setAutoColor(false);
        param.setLineColor(new WxMaCodeLineColor("0", "0", "0"));
        param.setHyaline(true);

        String qrImage = buildMAQrCode(param);

        // 再反向更新库
        taMiniappQrcode.setQrImage(qrImage);
        updateById(taMiniappQrcode);

        return qrImage;
    }

    /**
     * 生成小程序码, 并上传阿里云
     * @param param
     * @return
     * @throws WxErrorException
     */
    private String buildMAQrCode(WxUtils.AQrCodeParam param) throws WxErrorException, FileNotFoundException {
        WxMaQrcodeService qrcodeService = wxUtils.getService().getQrcodeService();
        File qrFile = qrcodeService.createWxaCodeUnlimit(param.getScene(),
                param.getPage(),
                param.getWidth(),
                param.isAutoColor(),
                param.getLineColor(),
                param.isHyaline());

        return ossUtils.putObject(qrFile);
    }
}
