package com.yunzhi.shigongli.service.impl;

import com.github.binarywang.wxpay.bean.notify.WxPayOrderNotifyResult;
import com.github.binarywang.wxpay.bean.notify.WxPayRefundNotifyResult;
import com.github.binarywang.wxpay.constant.WxPayConstants;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.DateUtils;
import com.yunzhi.shigongli.entity.TaOrder;
import com.yunzhi.shigongli.entity.TaOrderPay;
import com.yunzhi.shigongli.event.PaySuccessEvent;
import com.yunzhi.shigongli.event.RefundSuccessEvent;
import com.yunzhi.shigongli.mapper.TaOrderMapper;
import com.yunzhi.shigongli.mapper.TaOrderPayMapper;
import com.yunzhi.shigongli.mapper.TaOrderSubMapper;
import com.yunzhi.shigongli.service.ITaOrderPayService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 订单支付 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaOrderPayServiceImpl extends BaseServiceImpl<TaOrderPayMapper, TaOrderPay> implements ITaOrderPayService {

    @Autowired
    TaOrderPayMapper orderPayMapper;

    @Autowired
    TaOrderMapper taOrderMapper;

    @Autowired
    TaOrderSubMapper taOrderSubMapper;

    @Autowired
    ApplicationEventPublisher eventPublisher;

    /**
     * 支付回调
     * @param notifyResult
     * @throws Exception
     */
    @Override
    public void notifyOrder(WxPayOrderNotifyResult notifyResult) throws Exception {
        TaOrder taOrder = taOrderMapper.selectById(notifyResult.getOutTradeNo());
        boolean isSuccess = WxPayConstants.ResultCode.SUCCESS.equals(notifyResult.getResultCode());

        TaOrderPay orderPay = new TaOrderPay();
        orderPay.setOrderId(taOrder.getOrderId());
        orderPay.setPersonId(taOrder.getPersonId());
        orderPay.setCharges(notifyResult.getTotalFee());
        orderPay.setPayDate(DateUtils.from(notifyResult.getTimeEnd(), "yyyyMMddHHmmss"));
        orderPay.setStatus(isSuccess ? Constants.PAY_SUCCESS : Constants.PAY_FAIL);
        orderPay.setMessage(isSuccess ? null : notifyResult.getErrCodeDes());

        TaOrderPay origin = orderPayMapper.getByOrder(taOrder.getOrderId(), null);
        if (null != origin) {
            orderPay.setPayId(orderPay.getPayId());
            orderPayMapper.updateById(orderPay);
        } else {
            orderPayMapper.insert(orderPay);
        }

        // 更新订单为已支付
        if (isSuccess) {
            taOrderMapper.updateStatus(taOrder.getOrderId(), Constants.ORDER_PAYED);
            taOrderSubMapper.updateStatusByOrder(taOrder.getOrderId(), Constants.ORDER_PAYED);
        }

        // 支付成功, 发布返现事件
        if (isSuccess) {
            PaySuccessEvent evt = new PaySuccessEvent(this, taOrder);
            eventPublisher.publishEvent(evt);
        }
    }

    @Override
    public void refundNotifyOrder(WxPayRefundNotifyResult result) throws Exception {
        WxPayRefundNotifyResult.ReqInfo reqInfo = result.getReqInfo();
        if (null == reqInfo) {
            return;
        }

        // 退款成功
        boolean isSuccess = WxPayConstants.RefundStatus.SUCCESS.equals(reqInfo.getRefundStatus());
        if (!isSuccess) {
            return;
        }

        TaOrder taOrder = taOrderMapper.selectById(reqInfo.getOutTradeNo());
        TaOrderPay orderPay = new TaOrderPay();
        orderPay.setOrderId(taOrder.getOrderId());
        orderPay.setPersonId(taOrder.getPersonId());
        orderPay.setCharges(reqInfo.getRefundFee());
        orderPay.setPayDate(DateUtils.from(reqInfo.getSuccessTime(), "yyyyMMddHHmmss"));
        orderPay.setStatus(Constants.PAY_SUCCESS);
        orderPay.setMessage(null);

        // 如果退款单号 = R + 订单号, 说明是全订单退款
        // 否则是订单项退款
        if (!reqInfo.getOutRefundNo().equals("R"+taOrder.getOrderId())) {
            orderPay.setSubOrderId(reqInfo.getOutRefundNo().substring(1));
            taOrderSubMapper.updateStatus(orderPay.getSubOrderId(), Constants.ORDER_REFUND);
        } else {
            taOrderMapper.updateStatus(orderPay.getOrderId(), Constants.ORDER_REFUND);
        }

        orderPayMapper.insert(orderPay);

        RefundSuccessEvent evt = new RefundSuccessEvent(this, taOrder, null);
        eventPublisher.publishEvent(evt);
    }
}
