package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.SysConfig;
import com.yunzhi.shigongli.entity.TaPersonRecommender;
import com.yunzhi.shigongli.mapper.SysConfigMapper;
import com.yunzhi.shigongli.mapper.TaPersonRecommenderMapper;
import com.yunzhi.shigongli.service.ITaPersonRecommenderService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * <p>
 * 用户推广人 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaPersonRecommenderServiceImpl extends BaseServiceImpl<TaPersonRecommenderMapper, TaPersonRecommender> implements ITaPersonRecommenderService {

    @Autowired
    SysConfigMapper sysConfigMapper;

    @Autowired
    TaPersonRecommenderMapper personRecommenderMapper;

    @Async
    @Override
    public void addNewRecommender(String personId, String fromType, String recommender) throws Exception {
        if (isExists(personId, fromType, recommender)) {
            throw new Exception("当前客户还有未到期的推荐人");
        }

        // 读取系统配置
        String configCode = null;
        if (Constants.RECOMMEND_SHOP.equals(fromType)) {
            configCode = Constants.CONF_SHOP_RECOMMEND_VALID_DAYS;
        }
        if (Constants.RECOMMEND_SHOP.equals(fromType)) {
            configCode = Constants.CONF_HOTEL_RECOMMEND_VALID_DAYS;
        }

        SysConfig config = null == configCode ? null : sysConfigMapper.selectById(configCode);
        Integer validDays = 0;
        if (null != config && config.getStatus()) {
            validDays = Integer.valueOf(config.getConfigValue().trim());
        }

        LocalDateTime now = LocalDateTime.now();
        LocalDateTime expireDate = now.plusDays(validDays);

        // 生成推广记录
        TaPersonRecommender personRecommender = new TaPersonRecommender();
        personRecommender.setPersonId(personId);
        personRecommender.setFromType(fromType);
        personRecommender.setRecommender(recommender);
        personRecommender.setCreateDate(now);
        personRecommender.setExpireDate(expireDate);
        personRecommender.setStatus(Constants.STATUS_NORMAL);

        save(personRecommender);
    }

    private boolean isExists(String personId, String fromType, String recommender) {
        LocalDateTime now = LocalDateTime.now();
        LambdaQueryWrapper<TaPersonRecommender> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaPersonRecommender::getPersonId, personId)
                .eq(TaPersonRecommender::getFromType, fromType)
                .eq(TaPersonRecommender::getRecommender, recommender)
                .eq(TaPersonRecommender::getStatus, Constants.STATUS_NORMAL)
                .gt(TaPersonRecommender::getCreateDate, LocalDateTime.now())
                .lt(TaPersonRecommender::getExpireDate, now);

        return count(queryWrapper) > 0;
    }
}
